@@ -228,6 +228,88 @@ ConvRule fcitx_anthy_romaji_typing_rule[] = {
     {"n", "ん", ""},
     {"wyi", "ゐ", ""},
     {"wye", "ゑ", ""},
+    // New items from mozc
+    {"ca", "か", ""},
+    {"ci", "し", ""},
+    {"cu", "く", ""},
+    {"ce", "せ", ""},
+    {"co", "こ", ""},
+    {"cya", "ちゃ", ""},
+    {"cyi", "ちぃ", ""},
+    {"cyu", "ちゅ", ""},
+    {"cye", "ちぇ", ""},
+    {"cyo", "ちょ", ""},
+    {"vya", "ゔゃ", ""},
+    {"vyi", "ゔぃ", ""},
+    {"vyu", "ゔゅ", ""},
+    {"vye", "ゔぇ", ""},
+    {"vyo", "ゔょ", ""},
+    {"tsa", "つぁ", ""},
+    {"tsi", "つぃ", ""},
+    {"tse", "つぇ", ""},
+    {"tso", "つぉ", ""},
+    {"t'i", "てぃ", ""},
+    {"t'yu", "てゅ", ""},
+    {"d'i", "でぃ", ""},
+    {"d'yu", "でゅ", ""},
+    {"twa", "とぁ", ""},
+    {"twi", "とぃ", ""},
+    {"twu", "とぅ", ""},
+    {"twe", "とぇ", ""},
+    {"two", "とぉ", ""},
+    {"t'u", "とぅ", ""},
+    {"dwa", "どぁ", ""},
+    {"dwi", "どぃ", ""},
+    {"dwu", "どぅ", ""},
+    {"dwe", "どぇ", ""},
+    {"dwo", "どぉ", ""},
+    {"d'u", "どぅ", ""},
+    {"fya", "ふゃ", ""},
+    {"fyu", "ふゅ", ""},
+    {"fyo", "ふょ", ""},
+    {"hwa", "ふぁ", ""},
+    {"hwi", "ふぃ", ""},
+    {"hwe", "ふぇ", ""},
+    {"hwo", "ふぉ", ""},
+    {"hwyu", "ふゅ", ""},
+    {"xn", "ん", ""},
+    {"wu", "う", ""},
+    {"lyi", "ぃ", ""},
+    {"xyi", "ぃ", ""},
+    {"lye", "ぇ", ""},
+    {"xye", "ぇ", ""},
+    {"ye", "いぇ", ""},
+    {"xka", "ヵ", ""},
+    {"xke", "ヶ", ""},
+    {"lka", "ヵ", ""},
+    {"lke", "ヶ", ""},
+    {"qa", "くぁ", ""},
+    {"qi", "くぃ", ""},
+    {"qu", "く", ""},
+    {"qe", "くぇ", ""},
+    {"qo", "くぉ", ""},
+    {"kwa", "くぁ", ""},
+    {"kwi", "くぃ", ""},
+    {"kwu", "くぅ", ""},
+    {"kwe", "くぇ", ""},
+    {"kwo", "くぉ", ""},
+    {"gwa", "ぐぁ", ""},
+    {"gwi", "ぐぃ", ""},
+    {"gwu", "ぐぅ", ""},
+    {"gwe", "ぐぇ", ""},
+    {"gwo", "ぐぉ", ""},
+    {"swa", "すぁ", ""},
+    {"swi", "すぃ", ""},
+    {"swu", "すぅ", ""},
+    {"swe", "すぇ", ""},
+    {"swo", "すぉ", ""},
+    {"zwa", "ずぁ", ""},
+    {"zwi", "ずぃ", ""},
+    {"zwu", "ずぅ", ""},
+    {"zwe", "ずぇ", ""},
+    {"zwo", "ずぉ", ""},
+    {"lwa", "ゎ", ""},
+    {"whu", "う", ""},
 #if 0 /* emulate dead key */
 {"\\.",	"・",	""},
 {";r",	"→",	""},
